/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.codepipeline.model;

import java.io.Serializable;

/**
 * <p>
 * Represents the output of a start pipeline execution action.
 * </p>
 */
public class StartPipelineExecutionResult implements Serializable, Cloneable {

    /**
     * <p>
     * The unique system-generated ID of the pipeline that was started.
     * </p>
     */
    private String pipelineExecutionId;

    /**
     * <p>
     * The unique system-generated ID of the pipeline that was started.
     * </p>
     * 
     * @param pipelineExecutionId
     *        The unique system-generated ID of the pipeline that was started.
     */

    public void setPipelineExecutionId(String pipelineExecutionId) {
        this.pipelineExecutionId = pipelineExecutionId;
    }

    /**
     * <p>
     * The unique system-generated ID of the pipeline that was started.
     * </p>
     * 
     * @return The unique system-generated ID of the pipeline that was started.
     */

    public String getPipelineExecutionId() {
        return this.pipelineExecutionId;
    }

    /**
     * <p>
     * The unique system-generated ID of the pipeline that was started.
     * </p>
     * 
     * @param pipelineExecutionId
     *        The unique system-generated ID of the pipeline that was started.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public StartPipelineExecutionResult withPipelineExecutionId(
            String pipelineExecutionId) {
        setPipelineExecutionId(pipelineExecutionId);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getPipelineExecutionId() != null)
            sb.append("PipelineExecutionId: " + getPipelineExecutionId());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof StartPipelineExecutionResult == false)
            return false;
        StartPipelineExecutionResult other = (StartPipelineExecutionResult) obj;
        if (other.getPipelineExecutionId() == null
                ^ this.getPipelineExecutionId() == null)
            return false;
        if (other.getPipelineExecutionId() != null
                && other.getPipelineExecutionId().equals(
                        this.getPipelineExecutionId()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime
                * hashCode
                + ((getPipelineExecutionId() == null) ? 0
                        : getPipelineExecutionId().hashCode());
        return hashCode;
    }

    @Override
    public StartPipelineExecutionResult clone() {
        try {
            return (StartPipelineExecutionResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}
