/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticbeanstalk.model.transform;

import java.util.Map;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.elasticbeanstalk.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * CPUUtilization StAX Unmarshaller
 */
public class CPUUtilizationStaxUnmarshaller implements
        Unmarshaller<CPUUtilization, StaxUnmarshallerContext> {

    public CPUUtilization unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        CPUUtilization cPUUtilization = new CPUUtilization();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return cPUUtilization;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("User", targetDepth)) {
                    cPUUtilization.setUser(DoubleStaxUnmarshaller.getInstance()
                            .unmarshall(context));
                    continue;
                }

                if (context.testExpression("Nice", targetDepth)) {
                    cPUUtilization.setNice(DoubleStaxUnmarshaller.getInstance()
                            .unmarshall(context));
                    continue;
                }

                if (context.testExpression("System", targetDepth)) {
                    cPUUtilization.setSystem(DoubleStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("Idle", targetDepth)) {
                    cPUUtilization.setIdle(DoubleStaxUnmarshaller.getInstance()
                            .unmarshall(context));
                    continue;
                }

                if (context.testExpression("IOWait", targetDepth)) {
                    cPUUtilization.setIOWait(DoubleStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("IRQ", targetDepth)) {
                    cPUUtilization.setIRQ(DoubleStaxUnmarshaller.getInstance()
                            .unmarshall(context));
                    continue;
                }

                if (context.testExpression("SoftIRQ", targetDepth)) {
                    cPUUtilization.setSoftIRQ(DoubleStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return cPUUtilization;
                }
            }
        }
    }

    private static CPUUtilizationStaxUnmarshaller instance;

    public static CPUUtilizationStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new CPUUtilizationStaxUnmarshaller();
        return instance;
    }
}
